duckdb.arrow

Optional Apache Arrow C Data helpers for DuckDB JDBC.

Optional Apache Arrow C Data helpers for DuckDB JDBC.
raw docstring

duckdb.meta

DuckDB-specific result accessors and JDBC metadata introspection.

DuckDB-specific result accessors and JDBC metadata introspection.
raw docstring

duckdb.types

Read conversions for DuckDB JDBC nested values.

Extending java.util.Map is process-global across all next.jdbc use in this JVM. For DuckDB, this does not cause a problem: Java maps convert to Clojure maps.

Read conversions for DuckDB JDBC nested values.

Extending java.util.Map is process-global across all next.jdbc use in this
JVM. For DuckDB, this does not cause a problem: Java maps convert to Clojure maps.
raw docstring

No vars found in this namespace.

duckdb.udf

Helpers that only register Java-backed DuckDB scalar and table functions.

Registrations are process-global. duckdb_jdbc 1.5.4.0 has no way to remove them. Registered callbacks live for the lifetime of the JVM.

Helpers that only register Java-backed DuckDB scalar and table functions.

Registrations are process-global. duckdb_jdbc 1.5.4.0 has no way to remove
them. Registered callbacks live for the lifetime of the JVM.
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries