duckdb.arrow

Optional Apache Arrow C Data helpers for DuckDB JDBC.

Optional Apache Arrow C Data helpers for DuckDB JDBC.
raw docstring

arrow-exportclj

(arrow-export con query allocator)
(arrow-export con query allocator batch-size)

Runs query and returns a closeable ArrowReader that uses allocator.

query is a next.jdbc SQL/parameter vector or a SQL string. This function closes JDBC statement and result-set resources before it returns. The caller owns the reader and allocator. The caller must close the reader first.

Runs query and returns a closeable ArrowReader that uses allocator.

query is a next.jdbc SQL/parameter vector or a SQL string. This function
closes JDBC statement and result-set resources before it returns. The caller
owns the reader and allocator. The caller must close the reader first.
sourceraw docstring

register-arrow!clj

(register-arrow! con table stream)
(register-arrow! con table allocator reader)

Registers an Arrow C Data stream as table-name. Returns its lifetime handle.

Keep the returned ArrowArrayStream, its allocator, and its source ArrowReader open until DuckDB finishes the query that uses the replacement scan. Closing any of them early invalidates the zero-copy C Data buffers.

The four-argument form creates and exports an ArrowArrayStream from reader. It closes the stream if export or registration fails. The three-argument form registers an existing stream. The caller owns its lifetime.

Registers an Arrow C Data stream as table-name. Returns its lifetime handle.

Keep the returned ArrowArrayStream, its allocator, and its source ArrowReader
open until DuckDB finishes the query that uses the replacement scan. Closing
any of them early invalidates the zero-copy C Data buffers.

The four-argument form creates and exports an ArrowArrayStream from reader.
It closes the stream if export or registration fails. The three-argument form
registers an existing stream. The caller owns its lifetime.
sourceraw docstring

with-arrow-readerclj

(with-arrow-reader con query allocator f)
(with-arrow-reader con query allocator batch-size f)

Calls f with an ArrowReader for query. It always closes the reader after f.

The caller owns allocator and must keep it open for the duration of f.

Calls f with an ArrowReader for query. It always closes the reader after f.

The caller owns allocator and must keep it open for the duration of f.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries