duckdb.exec

DuckDB-native query execution helpers over next.jdbc.

DuckDB-native query execution helpers over next.jdbc.
raw docstring

bind-hugeint!clj

(bind-hugeint! stmt index value)

Binds an integer as DuckDB HUGEINT at the one-based parameter index.

Binds an integer as DuckDB HUGEINT at the one-based parameter index.
sourceraw docstring

bind-parameters!clj

(bind-parameters! stmt params)

Binds params in order on a reusable statement and returns stmt.

Binds params in order on a reusable statement and returns stmt.
sourceraw docstring

cancel!clj

(cancel! stmt)

Cancels stmt if it is currently executing and returns stmt.

Call this from a different thread than the executing query.

Cancels stmt if it is currently executing and returns stmt.

Call this from a different thread than the executing query.
sourceraw docstring

execute-with-timeout!clj

(execute-with-timeout! stmt timeout-ms)
(execute-with-timeout! stmt timeout-ms on-timeout)

Executes stmt and cancels it from another thread after timeout-ms.

on-timeout, when supplied, receives stmt immediately before cancellation. The callback can inspect query-progress. SQLExceptions from the interrupted execution are propagated to the calling thread.

Executes stmt and cancels it from another thread after timeout-ms.

on-timeout, when supplied, receives stmt immediately before cancellation.
The callback can inspect query-progress. SQLExceptions from the interrupted
execution are propagated to the calling thread.
sourceraw docstring

parameter-metadataclj

(parameter-metadata stmt)

Returns ordered JDBC parameter-type metadata for stmt.

Returns ordered JDBC parameter-type metadata for stmt.
sourceraw docstring

prepareclj

(prepare con sql)

Creates a reusable native DuckDB prepared statement.

The returned DuckDBPreparedStatement is AutoCloseable and should be scoped with with-open. Its Connection must remain open for the statement lifetime.

Creates a reusable native DuckDB prepared statement.

The returned DuckDBPreparedStatement is AutoCloseable and should be scoped
with with-open. Its Connection must remain open for the statement lifetime.
sourceraw docstring

profiling-informationclj

(profiling-information con format)

Returns native connection-local profiling output in format.

format is :query-tree, :json, :optimizer, :html, or :graphviz. Profiling must first be enabled on the same Connection with DuckDB SQL configuration, such as SET enable_profiling = 'no_output'.

Returns native connection-local profiling output in format.

format is :query-tree, :json, :optimizer, :html, or :graphviz. Profiling
must first be enabled on the same Connection with DuckDB SQL configuration,
such as SET enable_profiling = 'no_output'.
sourceraw docstring

query-progressclj

(query-progress stmt)

Returns the current connection-local progress reported for stmt.

Returns the current connection-local progress reported for stmt.
sourceraw docstring

read-chunksclj

(read-chunks stmt)

Returns native columnar chunks from a prepared statement.

Each chunk is a map of column-name keywords to value vectors. All values are copied before the native DuckDBChunkedResult is closed.

Returns native columnar chunks from a prepared statement.

Each chunk is a map of column-name keywords to value vectors. All values
are copied before the native DuckDBChunkedResult is closed.
sourceraw docstring

reduce-chunksclj

(reduce-chunks stmt f init)

Reduces native columnar chunks from a prepared statement.

Each chunk is a map of column-name keywords to value vectors. The native DuckDBChunkedResult is always closed before this function returns or throws.

Reduces native columnar chunks from a prepared statement.

Each chunk is a map of column-name keywords to value vectors. The native
DuckDBChunkedResult is always closed before this function returns or throws.
sourceraw docstring

reduce-streamingclj

(reduce-streaming ds sql xf f init)
(reduce-streaming ds sql opts xf f init)

Reduces a query using DuckDB's native streaming result mode.

sql is a next.jdbc SQL vector (or a SQL string). The Connection, statement, and ResultSet remain open until transduction finishes, including early termination via reduced. A pre-opened Connection cannot be used because JDBC_STREAM_RESULTS is a connection property.

Reduces a query using DuckDB's native streaming result mode.

sql is a next.jdbc SQL vector (or a SQL string). The Connection, statement,
and ResultSet remain open until transduction finishes, including early
termination via reduced. A pre-opened Connection cannot be used because
JDBC_STREAM_RESULTS is a connection property.
sourceraw docstring

return-metadataclj

(return-metadata stmt)

Returns the native statement return type and ordered result columns.

Returns the native statement return type and ordered result columns.
sourceraw docstring

set-fetch-size!clj

(set-fetch-size! stmt rows)

Sets the JDBC fetch size on stmt and returns stmt.

Sets the JDBC fetch size on stmt and returns stmt.
sourceraw docstring

set-query-timeout!clj

(set-query-timeout! stmt seconds)

Sets stmt's JDBC query timeout in seconds and returns stmt.

Sets stmt's JDBC query timeout in seconds and returns stmt.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries