Optional Apache Arrow C Data helpers for DuckDB JDBC.
Optional Apache Arrow C Data helpers for DuckDB JDBC.
Helpers for DuckDB-specific next.jdbc operations.
Helpers for DuckDB-specific next.jdbc operations.
DuckDB-native query execution helpers over next.jdbc.
DuckDB-native query execution helpers over next.jdbc.
DuckDB-specific result accessors and JDBC metadata introspection.
DuckDB-specific result accessors and JDBC metadata introspection.
Read conversions for DuckDB JDBC nested values.
Extending java.util.Map is process-global across all next.jdbc use in this JVM. For DuckDB, this does not cause a problem: Java maps convert to Clojure maps.
Read conversions for DuckDB JDBC nested values. Extending java.util.Map is process-global across all next.jdbc use in this JVM. For DuckDB, this does not cause a problem: Java maps convert to Clojure maps.
No vars found in this namespace.
Helpers that only register Java-backed DuckDB scalar and table functions.
Registrations are process-global. duckdb_jdbc 1.5.4.0 has no way to remove them. Registered callbacks live for the lifetime of the JVM.
Helpers that only register Java-backed DuckDB scalar and table functions. Registrations are process-global. duckdb_jdbc 1.5.4.0 has no way to remove them. Registered callbacks live for the lifetime of the JVM.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |