duckdb.core

Convenience helpers for DuckDB-specific next.jdbc operations.

Convenience helpers for DuckDB-specific next.jdbc operations.
raw docstring

attach!clj

(attach! ds path alias)
(attach! ds path alias opts)

Attaches the DuckDB database at path as alias.

Attaches the DuckDB database at path as alias.
sourceraw docstring

detach!clj

(detach! ds alias)

Detaches an attached DuckDB database alias.

Detaches an attached DuckDB database alias.
sourceraw docstring

duckdb-versionclj

(duckdb-version ds)

Returns the DuckDB version string for ds.

Returns the DuckDB version string for ds.
sourceraw docstring

file-datasourceclj

(file-datasource path)

Returns a next.jdbc datasource for a DuckDB database at path.

Returns a next.jdbc datasource for a DuckDB database at path.
sourceraw docstring

install-extension!clj

(install-extension! ds name)

Installs a DuckDB extension by name.

Installs a DuckDB extension by name.
sourceraw docstring

load-extension!clj

(load-extension! ds name)

Loads a DuckDB extension by name.

Loads a DuckDB extension by name.
sourceraw docstring

memory-datasourceclj

(memory-datasource)

Returns a next.jdbc datasource for an in-memory DuckDB database.

Each connection from a memory datasource is a SEPARATE in-memory database; hold one connection with next.jdbc/get-connection for multi-statement work.

Returns a next.jdbc datasource for an in-memory DuckDB database.

Each connection from a memory datasource is a SEPARATE in-memory database;
hold one connection with next.jdbc/get-connection for multi-statement work.
sourceraw docstring

read-csvclj

(read-csv ds path)
(read-csv ds path opts)

Reads path through DuckDB read_csv and returns next.jdbc result rows.

Reads path through DuckDB read_csv and returns next.jdbc result rows.
sourceraw docstring

read-parquetclj

(read-parquet ds path)
(read-parquet ds path opts)

Reads path through DuckDB read_parquet and returns next.jdbc result rows.

Reads path through DuckDB read_parquet and returns next.jdbc result rows.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries