Convenience helpers for DuckDB-specific next.jdbc operations.
Convenience helpers for DuckDB-specific next.jdbc operations.
(attach! ds path alias)(attach! ds path alias opts)Attaches the DuckDB database at path as alias.
Attaches the DuckDB database at path as alias.
(detach! ds alias)Detaches an attached DuckDB database alias.
Detaches an attached DuckDB database alias.
(duckdb-version ds)Returns the DuckDB version string for ds.
Returns the DuckDB version string for ds.
(file-datasource path)Returns a next.jdbc datasource for a DuckDB database at path.
Returns a next.jdbc datasource for a DuckDB database at path.
(install-extension! ds name)Installs a DuckDB extension by name.
Installs a DuckDB extension by name.
(load-extension! ds name)Loads a DuckDB extension by name.
Loads a DuckDB extension by name.
(memory-datasource)Returns a next.jdbc datasource for an in-memory DuckDB database.
Each connection from a memory datasource is a SEPARATE in-memory database; hold one connection with next.jdbc/get-connection for multi-statement work.
Returns a next.jdbc datasource for an in-memory DuckDB database. Each connection from a memory datasource is a SEPARATE in-memory database; hold one connection with next.jdbc/get-connection for multi-statement work.
(read-csv ds path)(read-csv ds path opts)Reads path through DuckDB read_csv and returns next.jdbc result rows.
Reads path through DuckDB read_csv and returns next.jdbc result rows.
(read-parquet ds path)(read-parquet ds path opts)Reads path through DuckDB read_parquet and returns next.jdbc result rows.
Reads path through DuckDB read_parquet and returns next.jdbc result rows.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |