DuckDB-specific result accessors and JDBC metadata introspection.
DuckDB-specific result accessors and JDBC metadata introspection.
(array rs column)Reads column from the current row as recursively converted Clojure data.
rs and its current row must remain open while this function is called.
Reads column from the current row as recursively converted Clojure data. rs and its current row must remain open while this function is called.
(blob rs column)Reads column from the current row as a java.sql.Blob.
Consume the Blob while rs and its current row remain open.
Reads column from the current row as a java.sql.Blob. Consume the Blob while rs and its current row remain open.
(capabilities con)Returns commonly useful JDBC capability flags reported by DuckDB.
Returns commonly useful JDBC capability flags reported by DuckDB.
(catalogs con)Returns the catalogs visible through JDBC metadata.
Returns the catalogs visible through JDBC metadata.
(columns con)(columns con
{:keys [catalog schema-pattern table-pattern column-pattern]
:or {table-pattern "%" column-pattern "%"}})Returns columns visible through JDBC metadata.
opts supports :catalog, :schema-pattern, :table-pattern, and :column-pattern. JDBC percent and underscore wildcards are accepted.
Returns columns visible through JDBC metadata. opts supports :catalog, :schema-pattern, :table-pattern, and :column-pattern. JDBC percent and underscore wildcards are accepted.
(driver-info con)Returns DuckDB driver, database product, and JDBC version information.
Returns DuckDB driver, database product, and JDBC version information.
(exported-keys con table)(exported-keys con table {:keys [catalog schema]})Returns foreign keys that reference table.
opts supports :catalog and :schema.
Returns foreign keys that reference table. opts supports :catalog and :schema.
(hugeint rs column)Reads column from the current row as a signed HUGEINT.
rs and its current row must remain open while this function is called.
Reads column from the current row as a signed HUGEINT. rs and its current row must remain open while this function is called.
(imported-keys con table)(imported-keys con table {:keys [catalog schema]})Returns foreign keys imported by table.
opts supports :catalog and :schema.
Returns foreign keys imported by table. opts supports :catalog and :schema.
(indexes con table)(indexes con
table
{:keys [catalog schema unique approximate]
:or {unique false approximate false}})Returns index metadata for table.
opts supports :catalog, :schema, :unique, and :approximate.
Returns index metadata for table. opts supports :catalog, :schema, :unique, and :approximate.
(json-node rs column)Reads column from the current row as a DuckDB JsonNode.
rs and its current row must remain open while this function is called.
Reads column from the current row as a DuckDB JsonNode. rs and its current row must remain open while this function is called.
(lazy-string rs column)Reads column from the current row through DuckDB's lazy string accessor.
rs and its current row must remain open while this function is called.
Reads column from the current row through DuckDB's lazy string accessor. rs and its current row must remain open while this function is called.
(offset-time rs column)Reads column from the current row as an OffsetTime.
rs and its current row must remain open while this function is called.
Reads column from the current row as an OffsetTime. rs and its current row must remain open while this function is called.
(primary-keys con table)(primary-keys con table {:keys [catalog schema]})Returns primary-key columns for table.
opts supports :catalog and :schema.
Returns primary-key columns for table. opts supports :catalog and :schema.
(schemas con)(schemas con {:keys [catalog schema-pattern]})Returns schemas visible through JDBC metadata.
opts supports :catalog and :schema-pattern.
Returns schemas visible through JDBC metadata. opts supports :catalog and :schema-pattern.
(struct rs column)Reads column from the current row as a keyword-keyed Clojure map.
Nested DuckDB ARRAY and STRUCT values are converted recursively. rs and its current row must remain open while this function is called.
Reads column from the current row as a keyword-keyed Clojure map. Nested DuckDB ARRAY and STRUCT values are converted recursively. rs and its current row must remain open while this function is called.
(tables con)(tables con
{:keys [catalog schema-pattern table-pattern types]
:or {table-pattern "%"}})Returns tables visible through JDBC metadata.
opts supports :catalog, :schema-pattern, :table-pattern, and :types. JDBC percent and underscore wildcards are accepted in pattern values.
Returns tables visible through JDBC metadata. opts supports :catalog, :schema-pattern, :table-pattern, and :types. JDBC percent and underscore wildcards are accepted in pattern values.
(type-info con)Returns the JDBC types supported by DuckDB.
Returns the JDBC types supported by DuckDB.
(uhugeint rs column)Reads column from the current row as an unsigned UHUGEINT.
rs and its current row must remain open while this function is called.
Reads column from the current row as an unsigned UHUGEINT. rs and its current row must remain open while this function is called.
(uuid rs column)Reads column from the current row as a UUID.
rs and its current row must remain open while this function is called.
Reads column from the current row as a UUID. rs and its current row must remain open while this function is called.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |